@@ -2,7 +2,7 @@ from nonebot import require
 from nonebot import logger
 from nonebot import on_command, on_regex
 from nonebot.permission import SUPERUSER
-from nonebot.adapters.cqhttp import Bot, GROUP, GROUP_ADMIN, GROUP_OWNER, GroupMessageEvent, MessageSegment
+from nonebot.adapters.onebot.v11 import Bot, GROUP, GROUP_ADMIN, GROUP_OWNER, GroupMessageEvent, MessageSegment
 from .data_source import fortune_manager
 from .utils import MainThemeList
 import re
@@ -83,9 +83,8 @@ async def _(bot: Bot, event: GroupMessageEvent):
 
 @refresh.handle()
 async def _(bot: Bot, event: GroupMessageEvent):
-    fortune_manager.reset_fortune()
-    logger.info("今日运势已刷新！")
-    await limit_setting.finish(message=f"今日运势已刷新!", at_sender=False)
+    fortune_manager.refresh()
+    await limit_setting.finish(message=f"抽签已全部刷新!", at_sender=False)
 
 # 重置每日占卜
 @scheduler.scheduled_job(
