@@ -1,5 +1,5 @@
-from nonebot.adapters.cqhttp import GroupMessageEvent
-from typing import Optional, Union, Dict, Tuple
+from nonebot.adapters.onebot.v11 import GroupMessageEvent
+from typing import Optional, Union, Dict
 from pathlib import Path
 import nonebot
 import random
@@ -11,7 +11,8 @@ except ModuleNotFoundError:
     import json
 
 _FORTUNE_PATH = nonebot.get_driver().config.fortune_path
-FORTUNE_PATH = os.path.join(os.path.dirname(__file__), "resource") if not _FORTUNE_PATH else _FORTUNE_PATH
+DEFAULT_PATH = os.path.join(os.path.dirname(__file__), "resource")
+FORTUNE_PATH = DEFAULT_PATH if not _FORTUNE_PATH else _FORTUNE_PATH
 
 from .utils import drawing
 
@@ -48,7 +49,7 @@ class FortuneManager:
         '''
         return self.setting["specific_rule"].get(limit)
 
-    def divine(self, limit: Optional[str], event: GroupMessageEvent) -> Tuple[str, bool]:
+    def divine(self, limit: Optional[str], event: GroupMessageEvent) -> tuple[str, bool]:
         '''
             今日运势抽签
         '''
@@ -153,4 +154,15 @@ class FortuneManager:
         with open(self.setting_file, 'w', encoding='utf-8') as f:
             json.dump(self.setting, f, ensure_ascii=False, indent=4)
 
+    '''
+        超管功能
+    '''
+    def refresh(self) -> None:
+        for group_id in self.user_data.keys():
+            for user_id in self.user_data[group_id].keys():
+                if self.user_data[group_id][user_id]["is_divined"] == True:
+                    self.user_data[group_id][user_id]["is_divined"] = False
+        
+        self.save_data()
+
 fortune_manager = FortuneManager(Path(FORTUNE_PATH))
\ No newline at end of file
